/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: Config.java 2122 2008-09-27 09:41:35Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.server;

import java.util.ArrayList;
import java.util.List;

import org.ow2.cmi.controller.server.filter.IFilter;

/**
 * @author Loris Bouzonnet
 *
 */
public abstract class Config implements IServerConfig {

    /**
     * Default duration to refresh the client view (in millis).
     */
    private static final int DEFAULT_REFRESH_TIME = 30000;

    /**
     * Default Policy Strategy Loader
     */
    public static final String DEFAULT_POLICY_STRATEGY_LOADER = "org.ow2.cmi.loader.DefaultPolicyStrategyLoader";

    /**
     * Default Policy Strategy Manager
     */
    public static final String DEFAULT_POLICY_STRATEGY_MANAGER = "org.ow2.cmi.controller.server.manager.DefaultPolicyStrategyManager";

    /**
     * Default values for the load.
     */
    private static final int DEFAULT_LOAD_FACTOR = 100;

    /**
     * Manager for the cluster view at the server-side.
     */
    private String policyStrategyLoaderClassname;


    /**
     * Indicate if a provider (of the cluster view) should be bound. True by
     * default.
     */
    private boolean providerBound = true;

    /**
     * Indicate if the local registry of this server can be accessed to lookup
     * unclustered objects.
     */
    private boolean registryBound = true;

    /**
     * Load factor.
     */
    private int loadFactor = DEFAULT_LOAD_FACTOR;

    /**
     * Protocols that must have a RMI connector.
     */
    private List<String> protocolsOfTheConnectors = new ArrayList<String>();

    private IFilter[] filters;

    private Class<?>[] interceptors;

    /**
     * Delay to refresh the client view.
     */
    private int delayToRefresh = DEFAULT_REFRESH_TIME;

    /**
     * Manager for the cluster view at the server-side.
     */
    private String policyStrategyManagerClassname = DEFAULT_POLICY_STRATEGY_MANAGER;

    /**
     * MBean domain name.
     */
    private String mbeanDomainName = "cmi";

    /**
     * MBean server name.
     */
    private String mbeanName = "CMIServer";

    /**
     * Auto configure components (by initializing them and starting them).
     * Should be disable if components are started independently.
     */
    private boolean autoConfigureComponents = true;


    public String getPolicyStrategyManagerClassname() {
        return policyStrategyManagerClassname;
    }

    public void setPolicyStrategyManagerClassname(
            final String policyStrategyManagerClassname) {
        this.policyStrategyManagerClassname = policyStrategyManagerClassname;
    }

    public String getPolicyStrategyLoaderClassname() {
        return policyStrategyLoaderClassname;
    }

    public void setPolicyStrategyLoaderClassname(
            final String policyStrategyLoaderClassname) {
        this.policyStrategyLoaderClassname = policyStrategyLoaderClassname;
    }

    public int getLoadFactor() {
        return loadFactor;
    }

    public void setLoadFactor(final int loadFactor) {
        this.loadFactor = loadFactor;
    }

    public List<String> getProtocolsOfTheConnectors() {
        return protocolsOfTheConnectors;
    }

    public void setProtocolsOfTheConnectors(final List<String> protocolsOfTheConnectors) {
        this.protocolsOfTheConnectors = protocolsOfTheConnectors;
    }

    public IFilter[] getFilters() {
        return filters;
    }

    public void setFilters(final IFilter[] filters) {
        this.filters = filters;
    }

    public Class<?>[] getInterceptors() {
        return interceptors;
    }

    public void setInterceptors(final Class<?>[] interceptors) {
        this.interceptors = interceptors;
    }

    public int getDelayToRefresh() {
        return delayToRefresh;
    }

    public void setDelayToRefresh(final int delayToRefresh) {
        this.delayToRefresh = delayToRefresh;
    }


    public boolean isProviderBound() {
        return providerBound;
    }

    public void setProviderBound(final boolean providerBound) {
        this.providerBound = providerBound;
    }

    public boolean isRegistryBound() {
        return registryBound;
    }

    public void setRegistryBound(final boolean registryBound) {
        this.registryBound = registryBound;
    }

    public void addLocalFilters(final IFilter[] filters) {
        // TODO Auto-generated method stub

    }

    public void addInterceptors(final Class<?>[] interceptors) {
        // TODO Auto-generated method stub

    }

    public String getMbeanDomainName() {
        return mbeanDomainName;
    }

    public void setMbeanDomainName(final String mbeanDomainName) {
        this.mbeanDomainName = mbeanDomainName;
    }

    public String getMbeanName() {
        return mbeanName;
    }

    public void setMbeanName(final String mbeanName) {
        this.mbeanName = mbeanName;

    }
    /**
     * @return true if components are managed by CMI and not externally.
     */
    public boolean isAutoConfigureComponents() {
        return this.autoConfigureComponents;
    }

    /**
     * Sets the flag for managing components in CMI.
     * @param autoConfigureComponents if true, managed by CMI
     */
    public void setAutoConfigureComponents(final boolean autoConfigureComponents) {
        this.autoConfigureComponents = autoConfigureComponents;
    }

}
